==> tomee-project-7.0.3-source-release.zip: tomee-project-7.0.3/container/openejb-core/src/test/java/org/apache/openejb/core/cmp/jpa/EmbeddedBillPk.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.core.cmp.jpa;

import javax.persistence.Column;
import javax.persistence.Embeddable;

@Embeddable
public class EmbeddedBillPk {
    private long billNumber;
    private long billVersion;
    private long billRevision;

    public EmbeddedBillPk() {

    }

    public EmbeddedBillPk(final long number, final long version, final long revision) {
        this.billNumber = number;
        this.billVersion = version;
        this.billRevision = revision;
    }

    @Column(name = "billNumber")
    public long getBillNumber() {
        return this.billNumber;
    }

    public void setBillNumber(final long number) {
        this.billNumber = number;
    }

    @Column(name = "billVersion")
    public long getBillVersion() {
        return this.billVersion;
    }

    public void setBillVersion(final long version) {
        this.billVersion = version;
    }

    @Column(name = "billRevision")
    public long getBillRevision() {
        return this.billRevision;
    }

    public void setBillRevision(final long revision) {
        this.billRevision = revision;
    }

    public boolean equals(final Object obj) {
        if (obj == this)
            return true;

        if (!(obj instanceof EmbeddedBillPk))
            return false;

        final EmbeddedBillPk pk = (EmbeddedBillPk) obj;

        if (billNumber != pk.billNumber)
            return false;

        if (billVersion != pk.billVersion)
            return false;

        if (billRevision != pk.billRevision)
            return false;

        return true;
    }

    public int hashCode() {
        return (billNumber + "." + billVersion + "." + billRevision).hashCode();
    }
}

==> tomee-project-10.1.2-source-release.zip: tomee-project-10.1.2/container/openejb-core/src/test/java/org/apache/openejb/core/cmp/jpa/EmbeddedBillPk.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.core.cmp.jpa;

import jakarta.persistence.Column;
import jakarta.persistence.Embeddable;

@Embeddable
public class EmbeddedBillPk {
    private long billNumber;
    private long billVersion;
    private long billRevision;

    public EmbeddedBillPk() {

    }

    public EmbeddedBillPk(final long number, final long version, final long revision) {
        this.billNumber = number;
        this.billVersion = version;
        this.billRevision = revision;
    }

    @Column(name = "billNumber")
    public long getBillNumber() {
        return this.billNumber;
    }

    public void setBillNumber(final long number) {
        this.billNumber = number;
    }

    @Column(name = "billVersion")
    public long getBillVersion() {
        return this.billVersion;
    }

    public void setBillVersion(final long version) {
        this.billVersion = version;
    }

    @Column(name = "billRevision")
    public long getBillRevision() {
        return this.billRevision;
    }

    public void setBillRevision(final long revision) {
        this.billRevision = revision;
    }

    public boolean equals(final Object obj) {
        if (obj == this)
            return true;

        if (!(obj instanceof EmbeddedBillPk))
            return false;

        final EmbeddedBillPk pk = (EmbeddedBillPk) obj;

        if (billNumber != pk.billNumber)
            return false;

        if (billVersion != pk.billVersion)
            return false;

        if (billRevision != pk.billRevision)
            return false;

        return true;
    }

    public int hashCode() {
        return (billNumber + "." + billVersion + "." + billRevision).hashCode();
    }
}
